@@ -1,9 +1,8 @@
-data_release <- "v0.2.0"
+data_release <- "v0.3.0"
 
 listar_pasta_cache_padrao <- function() {
   fs::path(
-    tools::R_user_dir("geocodebr", which = "cache"),
-    glue::glue("data_release_{data_release}")
+    tools::R_user_dir("geocodebr", which = "cache")
   )
 }
 
@@ -22,6 +21,7 @@ listar_arquivo_config <- function() {
 #' @param path Uma string. O caminho para o diretório usado para armazenar os
 #'   dados em cache.  Se `NULL`, o pacote usará um diretório versionado salvo
 #'   dentro do diretório retornado por [tools::R_user_dir()].
+#' @template verboso
 #'
 #' @return Retorna de forma invisível o caminho do diretório de cache.
 #'
@@ -32,8 +32,11 @@ listar_arquivo_config <- function() {
 #' definir_pasta_cache( path = NULL)
 #'
 #' @export
-definir_pasta_cache <- function(path) {
+definir_pasta_cache <- function(path,
+                                verboso = TRUE) {
+
   checkmate::assert_string(path, null.ok = TRUE)
+  checkmate::assert_logical(verboso, null.ok = FALSE)
 
   if (is.null(path)) {
     cache_dir <- listar_pasta_cache_padrao()
@@ -41,10 +44,12 @@ definir_pasta_cache <- function(path) {
     cache_dir <- fs::path_norm(path)
   }
 
-  cli::cli_inform(
-    c("i" = "Definido como pasta de cache {.file {cache_dir}}."),
-    class = "geocodebr_cache_dir"
-  )
+  if (isTRUE(verboso)) {
+    cli::cli_inform(
+      c("i" = "Definido como pasta de cache {.file {cache_dir}}."),
+      class = "geocodebr_cache_dir"
+      )
+    }
 
   arquivo_config <- listar_arquivo_config()
 
@@ -76,6 +81,7 @@ definir_pasta_cache <- function(path) {
 #'
 #' @export
 listar_pasta_cache <- function() {
+
   arquivo_config <- listar_arquivo_config()
 
   if (fs::file_exists(arquivo_config)) {
@@ -106,6 +112,7 @@ listar_pasta_cache <- function() {
 #'
 #' @export
 listar_dados_cache <- function(print_tree = FALSE) {
+
   checkmate::assert_logical(print_tree, any.missing = FALSE, len = 1)
 
   cache_dir <- listar_pasta_cache()
@@ -150,3 +157,57 @@ message_removed_cache_dir <- function(cache_dir) {
     )
   )
 }
+
+
+#' Atualiza dados no release local
+#'
+#' Detecta automaticamente se o release local esta desatualizado. Se sim, apaga
+#' a pasta de cache do release local e atualiza a versao do release no caminho
+#' da pasta
+#'
+#' @return Retorna de forma invisível o caminho do diretório de cache.
+#'
+#' @keywords internal
+apaga_data_release_antigo <- function() {
+
+  # list cache local
+  cache_dir <- geocodebr::listar_pasta_cache()
+
+  # detect all release paths
+  local_release_path <- list.dirs(cache_dir, recursive = T)[-1]
+  local_release_path <- local_release_path[grep('geocodebr_data_release_', local_release_path)]
+
+  new_data_release_dir <- fs::path(
+    cache_dir,
+    glue::glue("geocodebr_data_release_{data_release}")
+  )
+
+
+  if (identical(as.character(new_data_release_dir),local_release_path)) {
+    return(cache_dir)
+  }
+
+  # versao numerica dos releases local e do pacote
+  local_release <- gsub("[^0-9]", "", basename(local_release_path)) |> as.numeric()
+  pkg_release <- gsub("[^0-9]", "", data_release) |> as.numeric()
+
+  if (length(local_release)==0) {
+    return(cache_dir)
+  }
+
+  if (is.na(local_release) | local_release==pkg_release) {
+    return(cache_dir)
+  }
+
+
+  if (local_release != pkg_release) {
+
+    # deleta os dados do release local
+    suppressMessages(
+      geocodebr::deletar_pasta_cache()
+      )
+
+    return(cache_dir)
+  }
+
+}
