@@ -2,7 +2,7 @@
 #'
 #' Geocodifica endereços brasileiros com base nos dados do CNEFE. Os endereços
 #' de input devem ser passados como um `data.frame`, no qual cada coluna
-#' descreve um campo do endereço (logradouro, número, cep, etc). O resuldos dos
+#' descreve um campo do endereço (logradouro, número, cep, etc). Os resuldos dos
 #' endereços geolocalizados podem seguir diferentes níveis de precisão. Consulte
 #' abaixo a seção "Detalhes" para mais informações. As coordenadas de output
 #' utilizam o sistema de coordenadas geográficas SIRGAS 2000, EPSG 4674.
@@ -25,9 +25,8 @@
 #'    automaticamente. Por padrão, é `FALSE`, e a função retorna apenas o caso
 #'    mais provável. Para mais detalhes sobre como é feito o processo de
 #'    desempate, consulte abaixo a seção "Detalhes".
-#' @param resultado_sf Lógico. Indica se o resultado deve ser um objeto espacial
-#'    da classe `sf`. Por padrão, é `FALSE`, e o resultado é um `data.frame` com
-#'    as colunas `lat` e `lon`.
+#' @template h3_res
+#' @template resultado_sf
 #' @template verboso
 #' @template cache
 #' @template n_cores
@@ -45,7 +44,7 @@
 #'
 #' # ler amostra de dados
 #' data_path <- system.file("extdata/small_sample.csv", package = "geocodebr")
-#' input_df <- read.csv(data_path)
+#' input_df <- read.csv(data_path)[1:2,]
 #'
 #' fields <- geocodebr::definir_campos(
 #'   logradouro = "nm_logradouro",
@@ -70,6 +69,7 @@ geocode <- function(enderecos,
                     campos_endereco = definir_campos(),
                     resultado_completo = FALSE,
                     resolver_empates = FALSE,
+                    h3_res = NULL,
                     resultado_sf = FALSE,
                     verboso = TRUE,
                     cache = TRUE,
@@ -83,6 +83,7 @@ geocode <- function(enderecos,
   checkmate::assert_logical(verboso, any.missing = FALSE, len = 1)
   checkmate::assert_logical(cache, any.missing = FALSE, len = 1)
   checkmate::assert_number(n_cores, lower = 1, finite = TRUE)
+  checkmate::assert_number(h3_res, null.ok = TRUE, lower = 0, upper = 15)
   campos_endereco <- assert_and_assign_address_fields(
     campos_endereco,
     enderecos
@@ -160,7 +161,9 @@ geocode <- function(enderecos,
     endereco_encontrado = arrow::string(),
     logradouro_encontrado = arrow::string(),
     tipo_resultado = arrow::string(),
-    contagem_cnefe = arrow::int32()
+    contagem_cnefe = arrow::int32(),
+    desvio_metros = arrow::int32()
+
   )
 
   if (isTRUE(resultado_completo)) {
@@ -173,6 +176,7 @@ geocode <- function(enderecos,
       logradouro_encontrado = arrow::string(),
       tipo_resultado = arrow::string(),
       contagem_cnefe = arrow::int32(),
+      desvio_metros = arrow::int32(),
       #
       numero_encontrado = arrow::int32(),
       localidade_encontrada = arrow::string(),
@@ -180,7 +184,7 @@ geocode <- function(enderecos,
       municipio_encontrado = arrow::string(),
       estado_encontrado = arrow::string(),
       similaridade_logradouro = arrow::float16()
-      )
+    )
   }
 
   output_db_arrow <- arrow::arrow_table(schema = schema_output_db)
@@ -207,6 +211,8 @@ geocode <- function(enderecos,
 
     if (verboso) update_progress_bar(matched_rows, match_type)
 
+    # somente busca essa categoria match_type se todas colunas estiverem na base
+    # caso contrario, passa para proxima categoria
     if (all(key_cols %in% names(input_padrao))) {
 
       # select match function
@@ -215,7 +221,7 @@ geocode <- function(enderecos,
         } else if (match_type %in% number_interpolation_types ) { match_weighted_cases
         } else if (match_type %in% c(probabilistic_exact_types, probabilistic_types_no_number)) { match_cases_probabilistic
         } else if (match_type %in% probabilistic_interpolation_types) { match_weighted_cases_probabilistic
-          }
+        }
 
       n_rows_affected <- match_fun(
         con,
@@ -267,13 +273,27 @@ geocode <- function(enderecos,
   # casos de empate -----------------------------------------------
   if (nrow(output_df) > n_rows) {
     output_df <- trata_empates_geocode(output_df, resolver_empates, verboso)
-    }
+  }
 
   # drop geocodebr temp id column
   output_df[, tempidgeocodebr := NULL]
 
   if(isFALSE(resultado_completo)){ output_df[, logradouro_encontrado := NULL]}
 
+  # add H3
+  if( !is.null(h3_res) ) {
+
+    colname <- paste0(
+      'h3_',
+      formatC(h3_res, width = 2, flag = "0")
+    )
+
+    output_df[!is.na(lat),
+              {{colname}} := h3r::latLngToCell(lat = lat,
+                                               lng = lon,
+                                               resolution = h3_res)
+              ]
+    }
 
   # convert df to simple feature
   if (isTRUE(resultado_sf)) {
@@ -282,7 +302,7 @@ geocode <- function(enderecos,
       x = 'lon',
       y = 'lat',
       keep = TRUE
-      )
+    )
 
     sf::st_crs(output_sf) <- 4674
     return(output_sf)
