@@ -1,11 +1,13 @@
 match_cases <- function( # nocov start
-    con = con,
-    x = 'input_padrao_db',
-    y = 'filtered_cnefe',
-    output_tb = "output_db",
-    key_cols = key_cols,
-    match_type = match_type,
-    resultado_completo){
+  con = con,
+  x = "input_padrao_db",
+  y = "filtered_cnefe",
+  output_tb = "output_db",
+  key_cols = key_cols,
+  match_type = match_type,
+  resultado_completo){
+
+  # match_type = "dn01"
 
   # read corresponding parquet file
   table_name <- paste(key_cols, collapse = "_")
@@ -15,7 +17,11 @@ match_cases <- function( # nocov start
   table_name <- get_reference_table(match_type)
 
   # build path to local file
-  path_to_parquet <- paste0(listar_pasta_cache(), "/", table_name, ".parquet")
+  path_to_parquet <- fs::path(
+    listar_pasta_cache(),
+    glue::glue("geocodebr_data_release_{data_release}"),
+    paste0(table_name,".parquet")
+  )
 
   # determine geographical scope of the search
   input_states <- DBI::dbGetQuery(con, "SELECT DISTINCT estado FROM input_padrao_db;")$estado
@@ -29,6 +35,8 @@ match_cases <- function( # nocov start
     dplyr::filter(municipio %in% input_municipio) |>
     dplyr::compute()
 
+  # c <- collect(filtered_cnefe)
+  # summary(c$desvio_metros)
 
   # register filtered_cnefe to db
   duckdb::duckdb_register_arrow(con, "filtered_cnefe", filtered_cnefe)
@@ -39,7 +47,8 @@ match_cases <- function( # nocov start
     collapse = ' AND '
   )
 
-  # cols that cannot be null
+  # cols from x that cannot be null
+  # isso serve como filtro pre-join, pra fazer o join soh em quem nao foi encontrado ainda
   cols_not_null <-  paste(
     glue::glue("{x}.{key_cols} IS NOT NULL"),
     collapse = ' AND '
@@ -69,10 +78,14 @@ match_cases <- function( # nocov start
 
   # summarize query
   query_match <- glue::glue(
-    "INSERT INTO output_db (tempidgeocodebr, lat, lon, tipo_resultado, endereco_encontrado, contagem_cnefe {colunas_encontradas})
-      SELECT {x}.tempidgeocodebr, filtered_cnefe.lat, filtered_cnefe.lon,
-             '{match_type}' AS tipo_resultado, filtered_cnefe.endereco_completo AS endereco_encontrado,
-             filtered_cnefe.n_casos AS contagem_cnefe {additional_cols}
+    "INSERT INTO output_db (tempidgeocodebr, lat, lon, endereco_encontrado, tipo_resultado, desvio_metros, contagem_cnefe {colunas_encontradas})
+      SELECT {x}.tempidgeocodebr,
+        filtered_cnefe.lat,
+        filtered_cnefe.lon,
+        filtered_cnefe.endereco_completo AS endereco_encontrado,
+        '{match_type}' AS tipo_resultado,
+        filtered_cnefe.desvio_metros,
+        filtered_cnefe.n_casos AS contagem_cnefe {additional_cols}
       FROM {x}
       LEFT JOIN filtered_cnefe
       ON {join_condition}
@@ -81,6 +94,8 @@ match_cases <- function( # nocov start
 
   DBI::dbSendQueryArrow(con, query_match)
   # a <- DBI::dbReadTable(con, 'output_db')
+  # summary(a$desvio_metros)
+  # summary(a$lat)
 
   duckdb::duckdb_unregister_arrow(con, "filtered_cnefe")
 
