@@ -15,9 +15,17 @@ message_standardizing_addresses <- function() {
 }
 
 message_baixando_cnefe <- function() {
-  geocodebr_message(c("i" = "Baixandos dados do CNEFE"))
+  geocodebr_message(c("i" = "Baixando dados do CNEFE"))
+}
+
+message_usando_cnefe_local <- function() {
+  geocodebr_message(c("i" = "Utilizando dados do CNEFE armazenados localmente"))
 }
 
 message_looking_for_matches <- function() {
   geocodebr_message(c("i" = "Geolocalizando endere\u00e7os"))
 }
+
+message_preparando_output <- function() {
+  geocodebr_message(c("i" = "Preparando resultados"))
+}
